NAME: str = "python"
DESCRIPTION: str = """\
            A shortcut for calling the Python binary of the project.
            
            It requires an existing 'caos.yml' file and a virtual
            environment in the current directory.\
"""
CLI_USAGE_EXAMPLE: str = """\
            caos python    
            caos python [SCRIPT_FILE]
            caos python [SCRIPT_FILE] [ARGV]
"""
